;; C2011_Compare.Lsp            
;; CADALYST Systems Benchmark 2011 v5.3b
;; (c)Copyright 1996-2010, Art Liddle and CADALYST Magazine

;; NOTE:
;; 6-01-2010 (C2011, v5.3b): disabled navigation cube; renamed files for ACAD 2011; 
;; renamed benchmark to 2010
;; New routine for Compare options
;; 8-01-09: Used Autodesk's Gstest.arx files for updated 3D tests.
;; 2D test supports R2000 and newer; works with any driver.
;; New 3D test requires AutoCAD 2009 (Update #3) or newer.

(setq TST_VER "5.3b")
(setq TST_DATE "Jun-2010")

(setq TRNSFR_FILE "C2011_next")         ;;created on the fly
(setq TRNSFR_FILE_EXT "C2011_next.scr") ;;created on the fly
(setq DATA_FILE "c2011_data.dta")
(setq 3DTMP_FILE "c2011_3d.tmp")       ;;USED FOR RENAME FUNCTION ONLY
(setq CNFG_FILE "c2011_cnfg.dta")      ;;to turn info boxes on/off
(setq 3DCUR_FILE "c2011_current.dta")


;; Error handler
(defun *ERROR*  (MSG)
  (if (/= MSG "function cancelled")
    (if (= MSG "quit / exit abort")
      (princ)
      (princ (strcat "\nError:  " MSG "\n"))) ;_ end of if
    (princ)) ;_ end of if
  (princ)) ;_ end of defun

;; Test if file exists
(defun TEST_FILE  (FNAME / FILE)
  (setq FILE (open FNAME "r"))
  (if FILE
    (close FILE)
    (progn
      (alert
        (strcat
          "\nCan't find:  "
          FNAME
          "\n\nThis is a temporary file that contains the times for the current test."
          "\nYou must have already saved the current test times..."
          "\n\nClick Ok to exit, and try another option.") ;_ end of strcat
        ) ;_ end of alert
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;recall dialog box to try again
(setq compare_option 2)
(load "C2011_compare")
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;       (exit)
     )                           ; end progn
    )                                   ; end if
  )                                     ; end defun test_file


;; Create a list of lists (pairs) from a file
;; Single data per line in file
(defun LIST_IN (A_FILE / A_LIST ITEM1 ITEM2)
  (setq A_LIST (list))
  (while (setq ITEM1 (read-line A_FILE))
    (setq ITEM2 (read-line A_FILE))
    (setq A_LIST (append A_LIST (list (list ITEM1 ITEM2))))
  )
					; end while
)					; end defun list_in


;; Write a list of lists (pairs) to a file
;; Single data per line in file
(defun LIST_OUT  (A_LIST A_FILE A_CNTR / CNTR ITEM)
  (setq CNTR 0)
  (setq ITEM (nth CNTR A_LIST))
  (repeat A_CNTR 
    (write-line (car ITEM) A_FILE)
    (write-line (cadr ITEM) A_FILE)
    (setq CNTR (1+ CNTR))
    (setq ITEM (nth CNTR A_LIST)))      ; end while
 
 )                                     ; end defun list_out


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Read information in from config file
(setq FNAME CNFG_FILE)
(setq FILE (open FNAME "r"))
(setq CNFG_LIST (LIST_IN FILE))
(close FILE)
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;find On/Off value for compare option info boxes
(setq COMP_OPT_INFO (car (cdr (nth 9 CNFG_LIST))));;<<------------------verify number
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;start dcl interface
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;Cancel routine
(defun GO_CANCEL  ()
  (done_dialog 0)
  (unload_dialog DCL_ID)
  (princ)
  (quit))                               ;end go_cancel

(defun STD_CALL () (set_tile "error" ""))


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;Main Routine
;;load dialog, exit if not available
(setq DCL_ID (load_dialog "C2011_DCL_COMPARE.DCL"))
(if (not (new_dialog "C2011_DCL_COMPARE" DCL_ID))
  (exit)) ;_ end of if



;;set defaults if value not set
;;(if (= COMP_OPT_INFO nil)(setq COMP_OPT_INFO "On")(princ))
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;set default radio button
(cond ((= COMP_OPT_INFO  "On") (set_tile "info_boxes_on"  "1"));; any positive, non-zero number works
      ((= COMP_OPT_INFO "Off") (set_tile "info_boxes_off" "1"))
) ;_ end of cond


(if (= compare_option nil)(setq compare_option 4)(princ))
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;set default radio button
(cond ((= compare_option 1) (set_tile "save_times" "1"));; any positive, non-zero number works
      ((= compare_option 2) (set_tile "comp_times" "1"))
      ((= compare_option 3) (set_tile "save_comp_times" "1"))
      ((= compare_option 4) (set_tile "just_exit" "1"))
) ;_ end of cond
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;set value for next time, based on radio button selected
;;set options
(action_tile "info_boxes_on"      "(setq COMP_OPT_INFO \"On\"  )")
(action_tile "info_boxes_off"     "(setq COMP_OPT_INFO \"Off\" )")

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;set value for next time, based on radio button selected
;;set options
(action_tile "save_times"      "(setq compare_option 1)")
(action_tile "comp_times"      "(setq compare_option 2)")
(action_tile "save_comp_times" "(setq compare_option 3)")
(action_tile "just_exit"       "(setq compare_option 4)")

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;Ok and Cancel buttons
(action_tile "accept" "(done_dialog 4)")
(action_tile "cancel" "(go_cancel)")

;;load diaolog box
(start_dialog)
;;unload diaolog box
(unload_dialog DCL_ID)
;;finish cleanly
(princ)
;;Done

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Write current status of info boxes back to config file

(setq FNAME CNFG_FILE)
(setq FILE (open FNAME "w"))

;;write all data back except last pair--comp_opt_info
(LIST_OUT CNFG_LIST FILE 9);;one less than list--save space for new data


;;now, write comp_opt_info to end
(write-line "Compare Option's Informational Alert boxes:" FILE)
(write-line COMP_OPT_INFO FILE)
(close FILE)


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;act accordingly
;;;;;;;;;;;;;;;;;;;
(defun Comp_Opt_func ()

;;Option #1
(cond ((= compare_option 1) (progn

  (cond ((= COMP_OPT_INFO "On");;if info boxes are On--display
    (alert 
    "Save Current Test Times for Later Comparison, then EXIT:  \n
    The saved file includes test times only--there is no unique identifier.
    Choose a filename that will help you identify the test at a later date.
    \n\nNOTE: There will be no warning about overwriting a file, so be careful.");;end alert
  ));;end cond within cond

		(setq fname_data_rename (getfiled "Save Current Times to File (.dta) for Later Comparison:  " "" "dta" 33))
		(TEST_FILE 3DTMP_FILE)
      		(vl-file-rename 3DTMP_FILE fname_data_rename)
  (exit);;exit routine after renaming file
	);end progn
  );end cond

;;;;;;;;;;;;;;;;;;;
;;Option #2
     ((= compare_option 2) (progn

(cond ((= COMP_OPT_INFO "On");;if info boxes are On--display
(alert 
"Compare Current Test Times Against Previous Test Times:  \n
Select a previously saved file (*.dta) that contains the times you wish to compare against.\n
Be sure to compare the same type of tests--for example: 2D vs 2D.");;end alert
));;end cond within cond

		(setq fname_data_ref (getfiled "Select File (.dta) With Reference Times for Camparison:  " "" "dta" 8))
		); end progn
      );end cond

;;;;;;;;;;;;;;;;;;;
;;Option #3
      ((= compare_option 3) (progn

(cond ((= COMP_OPT_INFO "On");;if info boxes are On--display
(alert 
"Save Current Test Times and Compare Against Previous Test Times:  \n
The saved file includes test times only--there is no unique identifier.
Choose a filename that will help you identify the test at a later date.
\nThen select a previously saved file (*.dta) that contains the times you wish to compare against.\n
Be sure to compare the same type of tests--for example: 2D vs 2D.");;end alert
));;end cond within cond

		(setq fname_data_rename (getfiled "Save Current Times to File (.dta) for Later Comparison:  " "" "dta" 33))
		(TEST_FILE 3DTMP_FILE)
      		(vl-file-rename 3DTMP_FILE fname_data_rename)
(setq compare_option 2)
(comp_opt_func)
;;(setq fname_data_ref (getfiled "Select File (.dta) With Reference Times for Camparison:  " "" "dta" 8))

		); end progn

      );end cond

;;;;;;;;;;;;;;;;;;;
;;Option #4
      ((= compare_option 4)(exit));end cond

) ;_ end of cond statements

(check_length)

);; end defun com_opt_func
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun Start_comp ()
;; Save Name of Reference File to Data file
(setq FNAME DATA_FILE)
(setq FILE (open FNAME "a"))
(write-line "\n**********************************************************************************" FILE) ;_ end of write-line
(write-line "Comparison of Current Test Times Against Test Times From the Following File: " FILE)
(write-line  fname_data_ref FILE) ;_ end of write-line
(write-line "**********************************************************************************\n" FILE) ;_ end of write-line
(close FILE)
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;Call back to index file
;;but first erase screen to verify
(command "_erase" "_all" "")
;;(exit)
(load "C2011_indx")

);; end defun start_comp
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun Check_length ()
;;get length of current data file
  (setq FNAME 3DCUR_FILE)
  (setq FILE (open FNAME "r"))
  (setq 3D_cur_list (LIST_IN FILE))
  (close FILE)  
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;find length of file
(setq LEN_CUR (length 3D_cur_list))
(setq len_cur (1- len_cur))
;;find number of loops
(setq num_loops_cur (car (cdr (nth 0 3D_cur_list))));;<<------------------verify number
(setq num_loops_cur (atoi num_loops_cur))
(setq len_cur (/ len_cur num_loops_cur))
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;get length of base data file
  (setq FNAME fname_data_ref)
  (setq FILE (open FNAME "r"))
  (setq 3D_BASE_list (LIST_IN FILE))
  (close FILE)
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;find length of file  
(setq LEN_BASE (length 3D_BASE_list))
(setq len_base (1- len_base))
;;find number of loops
(setq num_loops_base (car (cdr (nth 0 3D_base_list))));;<<------------------verify number
(setq num_loops_base (atoi num_loops_base))
(setq len_base (/ len_base num_loops_base))
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(if (/= LEN_CUR LEN_BASE)
  (progn
    (alert
      (strcat
	"\nThe data file chosen for comparison:  \n\n" fname_data_ref
	"\n\ncontains data from the wrong type of test. "
	"\nYou must compare data files from the same type of test."
	"\nFor example, a 2D test must be compared against another 2D test."
	"\n\nClick Ok to exit and try again.") ;_ end of strcat
    ) ;_ end of alert
    (Comp_Opt_func)
  );; end progn
  (princ)  ;(start_comp)
);;end if
);; end defun check_length
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;Start actual compare process and error-checking routines
(Comp_Opt_func)

(start_comp)
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;




