;; C2011_Go.Lsp            
;; CADALYST Systems Benchmark 2010 v5.3b (released June-2010) 
;; (c)Copyright 1996-2010, Art Liddle and CADALYST Magazine


;; 6-01-2010 (C2011, v5.3b): disabled navigation cube; renamed files for ACAD 2011; 
;; changed name to c2010
;; 8-01-09: Used Autodesk's Gstest.arx files for updated 3D tests.
;; 7-01-08: Revised 3D tests: removed Flat, and Gouraud; added Conceptual and Realistic
;;                            adjusted number of repeats; adjusted base times


;; NOTE:
;; 2D test supports R2000 and newer; works with any driver.
;; New 3D test requires AutoCAD 2009 (Update #3) or newer.

       

(setq TST_VER "5.3b")
(setq TST_DATE "Jun-2010")


;; for R2000 MDI
(setq AVER (substr (getvar "acadver") 1 5))
(setq AVER_REAL (atof (getvar "acadver")))
(if (> AVER_REAL 15.0) 
 (progn
    (setq SDI_STATUS (getvar "sdi"))
    (if (/= SDI_STATUS 1)
      (progn
        (alert
          (strcat
            "\n   You must set SDI = 1, to turn multiple document interface off. "
            "\n\n   Then  *RESTART*  AutoCAD before running the benchmark... "
            "\n\n   Click Ok to exit."))
        (exit))                         ;end progn
      )                                 ;end if
    )                                   ;end progn
  )                                     ; end if


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;order that drawings are opened for test
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(setq DWG1 "c2011_5")
(setq DWG2 "c2011_1")
(setq DWG3 "c2011_6")
(setq DWG4 "c2011_2")
(setq DWG5 "c2011_7")
(setq DWG6 "c2011_3")
(setq DWG7 "c2011_8")
(setq DWG8 "c2011_4")

(setq DATA_FILE "C2011_data.dta")       ;;created on the fly
(setq CNFG_FILE "C2011_cnfg.dta")
(setq TRNSFR_FILE "C2011_next")         ;;created on the fly
(setq TRNSFR_FILE_EXT "C2011_next.scr") ;;created on the fly
(setq TIME_FILE "C2011_time") 
(setq 3DTMP_FILE "C2011_3d.tmp")        ;;created on the fly
(setq 3DCUR_FILE "c2011_current.dta")   ;;for new compare option

(setq NUM_2D 4) ;;<- num of 2d test dwgs
(setq NUM_3D 4) ;;<- num of 3d test dwgs

;; Error handler
(defun *ERROR*  (MSG)
  (if (/= MSG "function cancelled")
    (if (= MSG "quit / exit abort")
      (princ)
      (princ (strcat "\nError:  " MSG "\n"))) ;_ end of if
    (princ)) ;_ end of if
  (princ)) ;_ end of defun

;; Test if file exists
(defun TEST_FILE  (FNAME / FILE)
  (setq FILE (open FNAME "r"))
  (if FILE
    (close FILE)
    (progn
      (alert
        (strcat
          "\nCan't find:  "
          FNAME
          "\n\nIt's either missing or "
          "\nAutoCAD was not started from the folder containing the benchmark files."
          "\nSee Readme_C2011.txt for configuration instructions."
          "\n\nClick Ok to exit.") ;_ end of strcat
        ) ;_ end of alert
      (exit))                           ; end progn
    )                                   ; end if
  )                                     ; end defun test_file

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;This function is not need at this time...
;; Test if arx file exists
;;(defun TEST_FILE_arx  (FNAME / FILE)
;;  (setq FILE (open FNAME "r"))
;;  (if FILE
;;    (close FILE)
;;    (progn
;;      (alert
;;        (strcat
;;          "\nCan't find:  "
;;          FNAME
;;          "\n\nBased on your version of AutoCAD, you must rename the" 
;;          "\nappropriate gfxtest_xxxx.arx file to gfxtest.arx."
;;          "\nBe sure the renamed file is in the C2011 benchmark folder."
;;          "\nSee Readme_C2011.txt for details."
;;          "\n\nClick Ok to exit.") ;_ end of strcat
;;        ) ;_ end of alert
;;      (exit))                           ; end progn
;;    )                                   ; end if
;;  )                                     ; end defun test_file_arx

;; Create a list of lists (pairs) from a file
;; Single data per line in file
(defun LIST_IN  (A_FILE / A_LIST ITEM1 ITEM2)
  (setq A_LIST (list))
  (while (setq ITEM1 (read-line A_FILE))
    (setq ITEM2 (read-line A_FILE))
    (setq A_LIST (append A_LIST (list (list ITEM1 ITEM2)))) ;_ end of setq
    )                                   ; end while
  )                                     ; end defun list_in

;; Write a list of lists (pairs) to a file
;; Single data per line in file
(defun LIST_OUT  (A_LIST A_FILE / CNTR ITEM)
  (setq CNTR 0)
  (setq ITEM (nth CNTR A_LIST))
  (while ITEM
    (write-line (car ITEM) A_FILE)
    (write-line (cadr ITEM) A_FILE)
    (setq CNTR (1+ CNTR))
    (setq ITEM (nth CNTR A_LIST)))      ; end while
  )                                     ; end defun list_out

;; Start initialization
;; Check for test files first
(TEST_FILE "C2011_cnfg.dta")
(TEST_FILE "C2011_done.dwg")
(TEST_FILE "C2011_indx.lsp")

(TEST_FILE "C2011_std_3d2d.dta");;data for 3d2d
(TEST_FILE "C2011_std_3d.dta");;data for 3d only
(TEST_FILE "C2011_std_2d.dta");;data for 2d only


(TEST_FILE "C2011_time.lsp")
(TEST_FILE "C2011_dcl_go.dcl")
(TEST_FILE "C2011_compare.lsp");;for new compare option
(TEST_FILE "C2011_dcl_compare.dcl");;for new compare option
(TEST_FILE "C2011_indx.scr")

;;;moved to 3d test only (TEST_FILE_arx "gfxtest.arx")


;; Read default information in from file 
(setq FNAME CNFG_FILE)
(setq FILE (open FNAME "r"))
(setq CNFG_LIST (LIST_IN FILE))
(close FILE)

;;Set variables from list
(setq COMP_BRND (car (cdr (nth 0 CNFG_LIST))))
(setq CPU_TYPE (car (cdr  (nth 1 CNFG_LIST))))
(setq SYS_RAM (car (cdr   (nth 2 CNFG_LIST))))
(setq GRAPH_CRD (car (cdr (nth 3 CNFG_LIST))))
(setq GRAPH_DRV (car (cdr (nth 4 CNFG_LIST))))
(setq NOTE_TXT (car (cdr  (nth 5 CNFG_LIST))))
(setq NUM_LOOPS (car (cdr (nth 6 CNFG_LIST))))
(setq NUM_LOOPS (atoi NUM_LOOPS))
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;for new compare option
(setq COMP_OPT      (car (cdr (nth 7 CNFG_LIST))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;for new 3D or 2D options
(setq TEST_TYPE (car (cdr (nth 8 CNFG_LIST))));;;possible values = 3D2D  2D  3D
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(setq COMP_OPT_INFO (car (cdr (nth 9 CNFG_LIST))))
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;start dcl interface
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;Cancel routine
(defun GO_CANCEL  ()
  (done_dialog 0)
  (unload_dialog DCL_ID)
  (princ)
  (quit))                               ;end go_cancel

;;Main Routine
;;load dialog, exit if not available
(setq DCL_ID (load_dialog "C2011_DCL_GO.DCL"))
(if (not (new_dialog "C2011_DCL_GO" DCL_ID))
  (exit)) ;_ end of if

;;load image for logo
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(setq SLD_MAX_XX 900) ;; was 900

(setq SLD_MAX_YY 110) ;; was 110
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(start_image "c2011_logo")
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;adjusted to push authocad authority out of view
(slide_image -6  -10 SLD_MAX_XX SLD_MAX_YY "c2011_logo")  ;; was 11  0-->c2001 = 7  -20
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; name of SLD file
(end_image)


;;set default values for edit boxes
(set_tile "comp_brnd" COMP_BRND)
;; first name=DCL name, second= LSP variable
(set_tile "cpu_type" CPU_TYPE)
(set_tile "sys_ram" SYS_RAM)
(set_tile "graph_crd" GRAPH_CRD)
(set_tile "graph_drv" GRAPH_DRV)
;;(set_tile "acad_drv" ACAD_DRV)
(set_tile "note_txt" NOTE_TXT)
;;set loops default radio button
(cond ((= NUM_LOOPS 1) (set_tile "one_loop" "1"))
      ;; any positive, non-zero number works
      ((= NUM_LOOPS 3) (set_tile "three_loops" "1"))
      ((= NUM_LOOPS 5) (set_tile "five_loops" "1"))) ;_ end of cond

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;set Compare Option default radio button
(cond ((= COMP_OPT "On") (set_tile "comp_on" "1"))
      ;; any positive, non-zero number works
      ((= COMP_OPT "Off") (set_tile "comp_off" "1"))
) ;_ end of cond
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;set test type default radio button
(cond ((= TEST_TYPE "3D2D") (set_tile "test_3d2d" "1"))
      ((= TEST_TYPE "2D")   (set_tile "test_2d"   "1"))
      ((= TEST_TYPE "3D")   (set_tile "test_3d"   "1"))
);; end cond
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


;;define actions to take if edit box selected
;;get new values 
(action_tile "comp_brnd" "(setq COMP_BRND $value)")
(action_tile "cpu_type" "(setq CPU_TYPE $value)")
(action_tile "sys_ram" "(setq SYS_RAM $value)")
(action_tile "graph_crd" "(setq GRAPH_CRD $value)")
(action_tile "graph_drv" "(setq GRAPH_DRV $value)")
(action_tile "note_txt" "(setq NOTE_TXT $value)")

;;define actions to take if radio button selected
;;set loops
(action_tile "one_loop" "(setq NUM_LOOPS 1)")
(action_tile "three_loops" "(setq NUM_LOOPS 3)")
(action_tile "five_loops" "(setq NUM_LOOPS 5)")

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;define actions to take if radio button selected
;;New Compare Option
(action_tile "comp_on"  "(setq COMP_OPT \"On\")")
(action_tile "comp_off" "(setq COMP_OPT \"Off\")")
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;define actions to take if radio button selected
;;New 3D/2D Option
(action_tile "test_3d2d"  "(setq TEST_TYPE \"3D2D\")")
(action_tile "test_2d"    "(setq TEST_TYPE \"2D\")")
(action_tile "test_3d"    "(setq TEST_TYPE \"3D\")")
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


;;Ok and Cancel buttons
(action_tile "accept" "(done_dialog 4)")
(action_tile "cancel" "(go_cancel)")
;;load diaolog box
(start_dialog)
;;unload diaolog box
(unload_dialog DCL_ID)
;;finish cleanly
(princ)
;;Done


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;if 3d test, version of AutoCAD
(if (and (or (= TEST_TYPE "3D") (= TEST_TYPE "3D2D"))
	 (< AVER_REAL 17.2)
    )
  (progn
    (alert
      (strcat
	"\nThe new 3D test used in C2011 v5.3 does NOT work"
        "\nwith versions prior to AutoCAD 2009 (Update #3)."
      )
    )
    (exit)
  )
  (princ)
)					; end if
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;if 3d test, verify gfxtest.arx file is available
;;(if (or (= TEST_TYPE "3D") (= TEST_TYPE "3D2D")
;;    ); end or
;;    (TEST_FILE_arx "gstest.arx");;;back to gstest.arx
;;)                                     ;end if
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


(setq NUM_STRNG (rtos NUM_LOOPS 2 0))
;; Write current values back to configuration file
(setq FNAME CNFG_FILE)
(setq FILE (open FNAME "w"))
(write-line "Computer Brand:" FILE)
(write-line COMP_BRND FILE)
(write-line "CPU type/speed:" FILE)
(write-line CPU_TYPE FILE)
(write-line "System RAM:" FILE)
(write-line SYS_RAM FILE)
(write-line "Graphics card:" FILE)
(write-line GRAPH_CRD FILE)
(write-line "Graphics card driver:" FILE)
(write-line GRAPH_DRV FILE)
(write-line "Comments:" FILE)
(write-line NOTE_TXT FILE)
(write-line "Number of test loops:" FILE)
(write-line NUM_STRNG FILE)

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;    
;;new for compare option
(write-line "Compare Option:" FILE)
(write-line COMP_OPT FILE)

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;    
;;new for 3d/2d option
(write-line "Test Type:" FILE)
(write-line TEST_TYPE FILE)
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;    

(write-line "Compare Option's Informational Alert boxes:" FILE)
(write-line COMP_OPT_INFO FILE)
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;    

(close FILE)

;;check for all drawings
   (TEST_FILE "c2011_1.dwg")
   (TEST_FILE "c2011_2.dwg")
   (TEST_FILE "c2011_3.dwg")
   (TEST_FILE "c2011_4.dwg")
   (TEST_FILE "c2011_4a.dwg")
   (TEST_FILE "c2011_4b.dwg")
   (TEST_FILE "c2011_4c.dwg")
   (TEST_FILE "c2011_4d.dwg")
   (TEST_FILE "c2011_4e.dwg")
   (TEST_FILE "c2011_4f.dwg")
   (TEST_FILE "c2011_4g.dwg")
   (TEST_FILE "c2011_5.dwg")
   (TEST_FILE "c2011_6.dwg")
   (TEST_FILE "c2011_7.dwg")
   (TEST_FILE "c2011_8.dwg")

;; Get additional configuration info directly from
;; system
(setq PLAT (getvar "platform"))
(setq SCRNSZ (getvar "screensize"))
(setq SCRNSZ (strcat (rtos (car SCRNSZ) 2 0)
                     "x"
                     (rtos (cadr SCRNSZ) 2 0)
                     " pixels") ;_ end of strcat
      ) ;_ end of setq
(setq NOW (rtos (getvar "cdate") 2 4))
(setq MO (substr NOW 5 2))
(setq DY (substr NOW 7 2))
(setq YR (substr NOW 3 2))
(setq HR (atof (substr NOW 10 2)))
(if (= HR 0)
  (setq HR 12)) ;_ end of if
(if (> HR 12)
  (progn (setq HR (rtos (- HR 12) 2 0)) (setq TM "pm")) ;_ end of progn
  (progn (setq HR (rtos HR 2 0)) (setq TM "am"))) ;end if
(setq MN (substr NOW 12 2))
(setq DATE1 (strcat MO "-" DY "-" YR))
(setq TIME1 (strcat HR ":" MN TM))


;; Save test info to data file
(setq FNAME DATA_FILE)
(setq FILE (open FNAME "a"))

;;; ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(write-line "CADALYST Systems Benchmark 2011" FILE)
(write-line
  (strcat "Test version " TST_VER " ;  " TST_DATE)
  FILE) ;_ end of write-line
(write-line
  "(c)Copyright 1996-2010, Art Liddle and CADALYST Magazine"
  FILE) ;_ end of write-line
(write-line
  "***************************************************"
  FILE) ;_ end of write-line
(write-line (strcat "OS Platform               : " PLAT) FILE) ;_ end of write-line
(write-line (strcat "AutoCAD version           : " AVER) FILE) ;_ end of write-line
(write-line (strcat "Graphics Window size      : " SCRNSZ) FILE) ;_ end of write-line
(write-line
  (strcat "Test Date (Time)          : " DATE1 " (" TIME1 ")")  FILE) ;_ end of write-line
(write-line
  (strcat "Computer Brand            : " COMP_BRND)  FILE) ;_ end of write-line
(write-line
  (strcat "CPU Type                  : " CPU_TYPE)  FILE) ;_ end of write-line

(write-line (strcat "System RAM                : " SYS_RAM) FILE) ;_ end of write-line
(write-line
  (strcat "Graphics Card             : " GRAPH_CRD)  FILE) ;_ end of write-line

(write-line
  (strcat "Graphics Card driver      : " GRAPH_DRV)  FILE) ;_ end of write-line

;;(write-line
;;  (strcat "AutoCAD Driver            : " ACAD_DRV)  FILE) ;_ end of write-line
(write-line
  (strcat "Number of Test Loops      : " NUM_STRNG)  FILE) ;_ end of write-line
(write-line
  (strcat "Comment                   : " NOTE_TXT)  FILE) ;_ end of write-line
(write-line
  (strcat "**********************************************************************************") FILE) ;_ end of write-line
(close FILE)


(setq FNAME 3DTMP_FILE)
(setq FILE (open FNAME "w"))
(write-line "Loops" FILE)
(write-line NUM_STRNG FILE)
(close FILE)
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;for new compare option
(setq FNAME 3DCUR_FILE)
(setq FILE (open FNAME "w"))
(write-line "Loops" FILE)
(write-line NUM_STRNG FILE)
(close FILE)
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


;; Write transfer script
(setq FIRSTDWG DWG1)
(setq LOOP_DWGS_CNT (* NUM_LOOPS (+ NUM_2D NUM_3D)))

(setq FNAME TRNSFR_FILE_EXT)
(setq FILE (open FNAME "w"))
(write-line (strcat "_quit _y _open " FIRSTDWG) FILE)
(setq NOW (rtos (* (getvar "DATE") 86400.0) 2 4))
(write-line (strcat "(setq TIME_START " NOW " )") FILE) ;_ end of write-line
(write-line
  (strcat "(setq DWG_LIST '(\042"       DWG1           "\042 \042"
          DWG2           "\042 \042"    DWG3           "\042 \042"
          DWG4           "\042 \042"    DWG5           "\042 \042"
          DWG6           "\042 \042"    DWG7           "\042 \042"
          DWG8           "\042))") ;_ end of strcat
  FILE) ;_ end of write-line

(write-line
  (strcat "(setq LOOP_DWGS_CNT " (rtos LOOP_DWGS_CNT 2 0) ")") ;_ end of strcat
  FILE) ;_ end of write-line

(write-line (strcat "(load  \042" TIME_FILE "\042)") FILE) ;_ end of write-line
(close FILE)

(setq FNAME "tot_time.tmp")
(setq FILE (open FNAME "w"))
(write-line "Comment:" FILE)
(write-line NOTE_TXT FILE)
(write-line "Start time:" FILE)
(write-line NOW FILE)
(close FILE)

;; Transfer control to script
(command "_script" TRNSFR_FILE)
;; done C2011_go.lsp
