;; C2011_Indx.Lsp            
;; CADALYST Systems Benchmark 2010 v5.3b (released June-2010) 
;; (c)Copyright 1996-2010, Art Liddle and CADALYST Magazine

;; 6-01-2010 (C2011, v5.3b): disabled navigation cube; renamed files for ACAD 2011; 
;; changed name to c2010
;; 8-01-09: Used Autodesk's Gstest.arx files for updated 3D tests.
;; 7-01-08: Revised 3D tests: removed Flat and Gouraud; added Conceptual and Realistic
;; Adjusted base times as follows:

;; Running AutoCAD 2008 on Vista and a test workstation with 
;; an Intel 2.4GHz Core 2 (6600) CPU and NVIDIA FX 3700 graphics
;; card with standard driver:
;;      Set new Wireframe index equal to old Wireframe index
;;      Set new Realistic index equal to old Gouraud index		                      
;;      Arbitrarily set Hidden index and Conceptual index equal to 50

;; NOTE:
;; 2D test supports R2000 and newer
;;         works with any driver
;; 3D test requires AutoCAD 2009 v3

      
;; Adjusted factors
;; Total index  -->       (standard average of individual indexes)
;; 3D Graphics  --> 1/4   (standard average of each test)
;; 2D Graphics  --> 1/4   (inverse average of each test)
;; Disk         --> 1/4   (inverse average of each test)
;; CPU          --> 1/4   (inverse average of each test)


(setq 3DTMP_FILE "c2011_3d.tmp");;USED FOR RENAME FUNCTION ONLY
(setq 3DCUR_FILE "c2011_current.dta")

(setq TST_VER "5.3b")
(setq TST_DATE "June-2010")

(command "_save" "dustin" "_y")
(command "_dxfout" "connie" "_b")

(setq DWG1 "c2011_1")
(setq DWG2 "c2011_2")
(setq DWG3 "c2011_3")
(setq DWG4 "c2011_4")
(setq DWG5 "c2011_5")
(setq DWG6 "c2011_6")
(setq DWG7 "c2011_7")
(setq DWG8 "c2011_8")
(setq DATA_FILE "c2011_data.dta")
(setq CNFG_FILE "c2011_cnfg.dta")
(setq TRNSFR_FILE "c2011_next")
(setq TRNSFR_FILE_EXT "c2011_next.scr")

(setq NUM_2D 4);;;;<<---- number of 2d test dwgs
(setq NUM_3D 4);;;;<<---- number of 3d test dwgs

;; Error handler
(defun *ERROR* (MSG)
  (if (/= MSG "function cancelled")
    (if	(= MSG "quit / exit abort")
      (princ)
      (princ (strcat "\nError-->  " MSG "\n"))
    )					; end second if
    (princ)
  )					; end first if
)					; end defun *error*

;; Create a list of lists (pairs) from a file
;; Single data per line in file
(defun LIST_IN (A_FILE / A_LIST ITEM1 ITEM2)
  (setq A_LIST (list))
  (while (setq ITEM1 (read-line A_FILE))
    (setq ITEM2 (read-line A_FILE))
    (setq A_LIST (append A_LIST (list (list ITEM1 ITEM2))))
  )
					; end while
)					; end defun list_in

;; Strip out numbers from list of pairs 
(defun STRIP (A_LIST / B_LIST CNTR ITEM)
  (setq B_LIST (list))
  (setq CNTR 1)
  ;; change to 2 to omit first pair
  (while (setq ITEM (nth (1- CNTR) A_LIST))
    (setq B_LIST (append B_LIST (list (atof (cadr ITEM)))))
    (setq CNTR (1+ CNTR))
  )					; end while
  (setq B_LIST B_LIST)
)					; end defun strip


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Read current test results in from file
(defun OUTPUT_3D2D ()
  (setq FNAME 3DCUR_FILE)
  (setq FILE (open FNAME "r"))
  (setq 3D_LIST_ALL (LIST_IN FILE))
  (close FILE)  

  ;;strip away notes, leaving just numbers
  (setq TMP_LIST 3D_LIST_ALL)  ;; for later use
  (setq 3D_LIST_ALL (STRIP 3D_LIST_ALL))
  (setq LOOPS (fix (car 3D_LIST_ALL)))
  (setq 3D_LIST_ALL (cdr 3D_LIST_ALL))  ;;get name of tests
  (setq LEN (length TMP_LIST))
  (setq NUM_TEST (/ LEN NUM_3D LOOPS))
  (setq TST_NAME (list))
  (setq CNTR 1)  ;; skip number of loops
  (repeat NUM_TEST
    (setq NAM (list (car (nth CNTR TMP_LIST))))
    (setq TST_NAME (append TST_NAME NAM))
    (setq CNTR (1+ CNTR))
  )					;end repeat
  ;;figure average times
  (setq LEN (length 3D_LIST_ALL))
  (setq OFFSET (fix (/ LEN LOOPS)))
  (setq CNTR 0)
  (setq 3D_CUR (list))
  (repeat OFFSET
    (setq SUM 0)
    (setq CNTRX 0)
    (repeat LOOPS
      (setq SUM (+ SUM (nth (+ CNTR (* CNTRX OFFSET)) 3D_LIST_ALL)))
      (setq CNTRX (1+ CNTRX))
    )					;end repeat loops
    (setq AVG (/ SUM LOOPS))    ;; set minimum time
    (if	(< AVG 0.05)
      (setq AVG 0.05)
    )

    (setq AVG (list AVG))
    (setq 3D_CUR (append 3D_CUR AVG))
    (setq CNTR (1+ CNTR))
  )					;end repeat offset

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
  ;; Read base 3dtest results in from file
  (setq FNAME BASE_FILE)
  (setq FILE (open FNAME "r"))
  (setq 3D_BASE (LIST_IN FILE))
  (close FILE)

  ;;remove first pair- description
  (setq 3D_BASE (cdr 3D_BASE))
  ;;strip away notes, leaving just numbers
  (setq 3D_BASE (STRIP 3D_BASE))

  ;;calculate ratios of current times to base times
  (setq 3D_RATIOS (mapcar '/ 3D_CUR 3D_BASE))
  ;;calculate the test 3d average ratios
  (setq LEN (length 3D_RATIOS))
  (setq REP (fix (/ LEN NUM_3D)))
  (setq CNTR 0)
  (setq X NIL)
  (setq 3D_TEST (list))
  (setq ROW_LIST (list))
  (repeat REP
    (setq SUM 0)
    (setq CNTRX 0)
    (repeat NUM_3D
      (setq SUM
	     (+ SUM (setq X (nth (+ CNTR (* CNTRX REP)) 3D_RATIOS)))
      )
      (setq CNTRX (1+ CNTRX))
      (setq ROW_LIST (append ROW_LIST (list (/ 1 X))))
    )					;end repeat loops
    (setq AVG (list (/ 1 (/ SUM NUM_3D))))
    (setq 3D_TEST (append 3D_TEST AVG))
    (setq CNTR (1+ CNTR))
  )					;end repeat offset

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
  ;;modify to get real dwg average scores
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
  ;;calcualte the drawing 3d average ratios
  (setq LEN (length 3D_RATIOS))
  (setq REP (fix (/ LEN NUM_3D)))
  (setq CNTR 0)
  (setq 3D_DWGS (list))

  (repeat NUM_3D
    ;;calculate real average
    (setq CNTR (1+ CNTR))		;end repeat loops
    (setq offsetx (- (* cntr rep) rep))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
    ;; calculate 3d graphics index for each drawing--ADJUSTED TO GIVE STANDARD AVERAGE
    (setq 3D_INDX_dwg
	    (/   (+ (/ 1 (nth (+ offsetx 0) 3D_RATIOS))
		    (/ 1 (nth (+ offsetx 1) 3D_RATIOS))
		    (/ 1 (nth (+ offsetx 2) 3D_RATIOS))
		    (/ 1 (nth (+ offsetx 3) 3D_RATIOS)))
            4);;end first divide
    )
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

    ;; calculate 2d graphics index
    (setq 2d_indx_dwg
	   (/ 4
	      (+ (nth (+ offsetx 8) 3D_RATIOS)
		 (nth (+ offsetx 9) 3D_RATIOS)
		 (nth (+ offsetx 10) 3D_RATIOS)
		 (nth (+ offsetx 11) 3D_RATIOS)
	      )
	   )
    )

    ;; calculate Disk index
    (setq disk_indx_dwg
	   (/ 3
	      (+ (nth (+ offsetx 4) 3D_RATIOS)
		 (nth (+ offsetx 5) 3D_RATIOS)
		 (nth (+ offsetx 6) 3D_RATIOS)
	      )
	   )
    )

    ;; calculate CPU index
    (setq cpu_indx_dwg
	   (/ 1
	      (+ (nth (+ offsetx 7) 3D_RATIOS)
	      )
	   )
    )
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;; 
    ;; calculate 3d total index
    (setq 3d2dtotal_indx_dwg
	   (/ (+ 3D_INDX_dwg
		 2d_indx_dwg
		 disk_indx_dwg
		 cpu_indx_dwg
	      )
	      4
	   )
    )					; end setq
    (setq 3d2dtotal_indx_dwg (list 3d2dtotal_indx_dwg))
    (setq 3D_DWGS (append 3D_DWGS 3d2dtotal_indx_dwg))
  )					; end repeat
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
  ;; calculate 3d graphics index--MODIFIED TO GIVE STANDARD AVERAGE
  (setq	3D_INDX
	 (/ 
	    (+ (nth 0 3D_TEST)
	       (nth 1 3D_TEST)
	       (nth 2 3D_TEST)
	       (nth 3 3D_TEST))
	 4 );;END DIVIDE
  )
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


  ;; calculate 2d graphics index
  (setq	2d_indx
	 (/ 4
	    (+ (/ 1 (nth 8 3D_TEST))
	       (/ 1 (nth 9 3D_TEST))
	       (/ 1 (nth 10 3D_TEST))
	       (/ 1 (nth 11 3D_TEST))
	    )
	 )
  )
  ;; calculate disk index
  (setq	disk_indx
	 (/ 3
	    (+ (/ 1 (nth 4 3D_TEST))
	       (/ 1 (nth 5 3D_TEST))
	       (/ 1 (nth 6 3D_TEST))
	    )
	 )
  )
  ;; calculate CPU index
  (setq	cpu_indx
	 (/ 1
	    (+ (/ 1 (nth 7 3D_TEST))
	    )
	 )
  )
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;; 
  ;; calculate 3d total index

  ;; calculate 3d total index
  ;; set factors for each test
  (setq	3d2dtotal_indx
	 (/ (+ (* 1 3D_INDX)
	       (* 1 2d_indx)
	       (* 1 disk_indx)
	       (* 1 cpu_indx)
	    )
	    4
	 )
  )					; end setq
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;; 

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;; 
;;adjust number of digits after decimal based on main index value
 (cond
       ((>= 3d2dtotal_indx 100) (progn (setq fillspace "")    (setq filldash "")                 (setq decdigits 0)))
       ((>= 3d2dtotal_indx 10)  (progn (setq fillspace "  ")  (setq filldash " - - - - -")       (setq decdigits 1)))
       ((>= 3d2dtotal_indx 0)   (progn (setq fillspace "   ") (setq filldash " - - - - - - - -") (setq decdigits 2)))
      );;end cond
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;; 

  ;; Begin writng index information to file and drawing
  (setq FNAME DATA_FILE)
  (setq FILE (open FNAME "a"))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;; 
  ;;  Write drawing names to file/screen
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;; 
  (command "_text"
	   ""
	   (write-line
	     (strcat                 "Drawing (3D)===>>          "
		fillspace     DWG5   "    "
		fillspace     DWG6   "    "
		fillspace     DWG7   "    "
		fillspace     DWG8	
 		    ); end strcat
	     FILE
	   ); end write-line
  ); end command					

  (command "_text"
	   ""
	   (write-line
	     (strcat                 "Drawing (2D)===>>          "
		fillspace     DWG1   "    "
		fillspace     DWG2   "    "
		fillspace     DWG3   "    "
		fillspace     DWG4	
                fillspace            "      Test Index"
		    ); end strcat
	     FILE
	   ); end write-line
  ); end command					


  (command
    "_text"
    ""
    (write-line (strcat
      "- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -"
      filldash); end strcat
      FILE
    )
  )

  (setq CNTR 0)
  (setq CNTRX 0)
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;  
  ;; print one line of scores and average for each test
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;    
  (repeat NUM_TEST
    (setq XX (nth CNTR ROW_LIST))
    (setq ajl1 xx)

    ;;add spaces BEFORE, based on length of next score to post
    (setq X (cond ((< XX 9.9) "       ");; adjust here
		  ((and (>= XX 9.9) (< XX 99.9)) "      ");; adjust here
		  ((and (>= XX 99.9) (< XX 999.9)) "     ");; adjust here
		  ((and (>= XX 999.9) (< XX 99999.9)) "    ");; adjust here
	    )				;end cond-->> increase last top value to avoid error
    )					;end setq
    (setq ajl1b x)

    (repeat NUM_3D

      ;;find length of test score coming up next 
      (setq cntrxxx (1+ cntr))
      (setq XXX (nth cntrxxx row_list))

      ;;add spaces AFTER, based on score comming up next test
      (setq
	X
	 (strcat X
		 (rtos (nth CNTR ROW_LIST) 2 decdigits);; adjust here

		 (cond ((< XXX 9.9) "          ");; adjust here
		       ((and (>= XXX 9.9) (< XXX 99.9)) "         ");; adjust here
		       ((and (>= XXX 99.9) (< XXX 999.9)) "        ");; adjust here
		       ((and (>= XXX 999.9) (< XXX 99999.9)) "       ");; adjust here
		 )			;end cond-->> increase last top value to avoid error
	 )				;end strcat
      )					;end setq

      (setq ajl2 x)
      (setq CNTR (1+ CNTR))
    )					;end repeat num_3d

    ;;grab test name and append to front of list
    (setq X (strcat (nth CNTRX TST_NAME) X))

    (setq ajl3 x)

    ;;format output of score for each test
    ;;get test score
    (setq xtemp (nth CNTRX 3D_TEST))
    (setq ajl4 xtemp)

    ;;add spaces based on length of previous score posted and average test score
    (setq xtempx
	   (cond ((< XXX 9.9) "")
		 ((and (>= XXX 9.9) (< XXX 99.9)) " ")
		 ((and (>= XXX 99.9) (< XXX 999.9)) "  ")
		 ((and (>= XXX 999.9) (< XXX 99999.9)) "   ")
	   )				;end cond-->> increase last top value to avoid error
    )					; end setq xtempx

    (setq xxtemp
	   (cond ((< Xtemp 9.9) "  ");; adjust here
		 ((and (>= Xtemp 9.9) (< Xtemp 99.9)) " ");; adjust here
		 ((and (>= Xtemp 99.9) (< Xtemp 999.9)) "");; adjust here
		 ((and (>= Xtemp 999.9) (< Xtemp 99999.9)) "");; adjust here
	   )				;end cond-->> increase last top value to avoid error
    )					;end setq
    ;;append spaces to string
    (setq X (strcat X xtempx))
    (setq X (strcat X xxtemp))

    (setq ajl5 x)
    ;;append spaces on score to string
    (setq X (strcat X (rtos (nth CNTRX 3D_TEST) 2 decdigits)));; adjust here
    (setq ajl6 x)
    (command "_text" "" (write-line X FILE))
    (setq CNTRX (1+ CNTRX))
    (setq X "")

  )					;end repeat num_test
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;  
  ;;done with individual scores

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;  
  ;;write dwg averages
  (command
    "_text"
    ""
    (write-line (strcat
      "- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -"
      filldash); end strcat
      FILE
    )
    ;;end write-line
  )
  ;;end command


  ;;output 3d DWG AVERAGES HERE 
  ;;calcualte spaces to add between scores based on length of score
  ;;prime the pump

  (setq idi (nth 0 3D_DWGS))
  (setq	space1
	 (cond ((< idi 9.9) "        ");; adjust here
	       ((and (>= idi 9.9) (< idi 99.9)) "       ");; adjust here
	       ((and (>= idi 99.9) (< idi 999.9)) "      ");; adjust here
	       ((and (>= idi 999.9) (< idi 99999.9)) "     ");; adjust here
	 )				;end cond-->> increase last top value to avoid error
  )					; end setq space1

  (setq idi (nth 1 3D_DWGS))
  (setq	space2  
	 (cond ((< idi 9.9) "          ");; adjust here
	       ((and (>= idi 9.9) (< idi 99.9)) "         ");; adjust here
	       ((and (>= idi 99.9) (< idi 999.9)) "        ");; adjust here
	       ((and (>= idi 999.9) (< idi 99999.9)) "       ");; adjust here
	 )				;end cond-->> increase last top value to avoid error

  )					; end setq space2

  (setq idi (nth 2 3D_DWGS))
  (setq	space3
	 (cond ((< idi 9.9) "          ")
	       ((and (>= idi 9.9) (< idi 99.9)) "         ");; adjust here
	       ((and (>= idi 99.9) (< idi 999.9)) "        ");; adjust here
	       ((and (>= idi 999.9) (< idi 99999.9)) "       ");; adjust here
	 )				;end cond-->> increase last top value to avoid error

  )					; end setq space3

  (setq idi (nth 3 3D_DWGS))
  (setq	space4
	 (cond ((< idi 9.9) "          ")
	       ((and (>= idi 9.9) (< idi 99.9)) "         ");; adjust here
	       ((and (>= idi 99.9) (< idi 999.9)) "        ");; adjust here
	       ((and (>= idi 999.9) (< idi 99999.9)) "       ");; adjust here
	 )				;end cond-->> increase last top value to avoid error

  )					; end setq space4

  (command "_text"
	   ""
	   (write-line
	     (strcat
	       "Individual Dwg Index    "
	       space1
	       (rtos (nth 0 3D_DWGS) 2 decdigits);; adjust here
	       space2
	       (rtos (nth 1 3D_DWGS) 2 decdigits);; adjust here
	       space3
	       (rtos (nth 2 3D_DWGS) 2 decdigits);; adjust here
	       space4
	       (rtos (nth 3 3D_DWGS) 2 decdigits);; adjust here
	     )				;end strcat

	     FILE
	   )				;end write-line
  )					;end command

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
					;write total index number
  (command "_text" "" (write-line "" FILE))
  (command "_text"
	   ""
	   (write-line "********************************" FILE)
  )

  ;;add spaces based on digits in score
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
  (setq x 3d2dtotal_indx)
  (setq	xx
	 (cond ((< x 9.9) "   ")
	       ((and (>= x 9.9) (< x 99.9)) "  ")
	       ((and (>= x 99.9) (< x 999.9)) " ")
	       ((and (>= x 999.9) (< x 99999.9)) "")
	 )				;end cond-->> increase last top value to avoid error
  )					; end setq xx
  (command
    "_text"
    ""
    (write-line
      (strcat "C2011 Total Index   = "
	      xx
	      (rtos 3d2dtotal_indx 2 decdigits);; adjust here
      )
      FILE
    )
  )

  (command "_text"
	   ""
	   (write-line "********************************" FILE)
  )

  ;;add spaces based on digits in score
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
  (setq x 3D_INDX)
  (setq	xx
	 (cond ((< x 9.9) "   ")
	       ((and (>= x 9.9) (< x 99.9)) "  ")
	       ((and (>= x 99.9) (< x 999.9)) " ")
	       ((and (>= x 999.9) (< x 99999.9)) "")
	 )				;end cond-->> increase last top value to avoid error
  )					; end setq xx
  (command "_text"
	   ""
	   (write-line			;   "
	     (strcat "3D Graphics Index   = " xx (rtos 3D_INDX 2 decdigits));; adjust here
	     FILE
	   )
  )

  ;;add spaces based on digits in score
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
  (setq x 2d_indx)
  (setq	xx
	 (cond ((< x 9.9) "   ")
	       ((and (>= x 9.9) (< x 99.9)) "  ")
	       ((and (>= x 99.9) (< x 999.9)) " ")
	       ((and (>= x 999.9) (< x 99999.9)) "")
	 )				;end cond-->> increase last top value to avoid errors
  )					; end setq xx  
  (command "_text"
	   ""
	   (write-line			;   "
	     (strcat "2D Graphics Index   = " xx (rtos 2d_indx 2 decdigits));; adjust here
	     FILE
	   )
  )

  ;;add spaces based on digits in score
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
  (setq x disk_indx)
  (setq	xx
	 (cond ((< x 9.9) "   ")
	       ((and (>= x 9.9) (< x 99.9)) "  ")
	       ((and (>= x 99.9) (< x 999.9)) " ")
	       ((and (>= x 999.9) (< x 99999.9)) "")
	 )				;end cond-->> increase last top value to avoid error
  )					; end setq xx  
  (command "_text"
	   ""
	   (write-line			;   "
	     (strcat "Disk Index          = "
		     xx
		     (rtos disk_indx 2 decdigits);; adjust here
	     )
	     FILE
	   )
  )

  ;;add spaces based on digits in score
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
  (setq x cpu_indx)
  (setq	xx
	 (cond ((< x 9.9) "   ")
	       ((and (>= x 9.9) (< x 99.9)) "  ")
	       ((and (>= x 99.9) (< x 999.9)) " ")
	       ((and (>= x 999.9) (< x 99999.9)) "")
	 )				;end cond-->> increase last top value to avoid error
  )					; end setq xx  
  (command
    "_text"
    ""
    (write-line				;   "       
      (strcat "CPU Index           = " xx (rtos cpu_indx 2 decdigits));; adjust here
      FILE
    )
  )

  (command "_text"
	   ""
	   (write-line "********************************" FILE)
  )
  (close FILE)
);; end output_3d2d
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;




;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Read current test results in from file
(defun OUTPUT_2D ()
  (setq FNAME 3DCUR_FILE)
  (setq FILE (open FNAME "r"))
  (setq 3D_LIST_ALL (LIST_IN FILE))
  (close FILE)  
  ;;strip away notes, leaving just numbers
  (setq TMP_LIST 3D_LIST_ALL)  ;; for later use
  (setq 3D_LIST_ALL (STRIP 3D_LIST_ALL))
  (setq LOOPS (fix (car 3D_LIST_ALL)))
  (setq 3D_LIST_ALL (cdr 3D_LIST_ALL))  ;;get name of tests
  (setq LEN (length TMP_LIST))
  (setq NUM_TEST (/ LEN NUM_3D LOOPS))
  (setq TST_NAME (list))
  (setq CNTR 1)  ;; skip number of loops
  (repeat NUM_TEST
    (setq NAM (list (car (nth CNTR TMP_LIST))))
    (setq TST_NAME (append TST_NAME NAM))
    (setq CNTR (1+ CNTR))
  )					;end repeat

  ;;figure average times
  (setq LEN (length 3D_LIST_ALL))
  (setq OFFSET (fix (/ LEN LOOPS)))
  (setq CNTR 0)
  (setq 3D_CUR (list))
  (repeat OFFSET
    (setq SUM 0)
    (setq CNTRX 0)
    (repeat LOOPS
      (setq SUM (+ SUM (nth (+ CNTR (* CNTRX OFFSET)) 3D_LIST_ALL)))
      (setq CNTRX (1+ CNTRX))
    )					;end repeat loops
    (setq AVG (/ SUM LOOPS))    ;; set minimum time
    (if	(< AVG 0.05)
      (setq AVG 0.05)
    )

    (setq AVG (list AVG))
    (setq 3D_CUR (append 3D_CUR AVG))
    (setq CNTR (1+ CNTR))
  )					;end repeat offset

  ;; Read base 3dtest results in from file
  (setq FNAME BASE_FILE)
  (setq FILE (open FNAME "r"))
  (setq 3D_BASE (LIST_IN FILE))
  (close FILE)
  ;;remove first pair- description
  (setq 3D_BASE (cdr 3D_BASE))
  ;;strip away notes, leaving just numbers
  (setq 3D_BASE (STRIP 3D_BASE))

  ;;calculate ratios of current times to base times
  (setq 3D_RATIOS (mapcar '/ 3D_CUR 3D_BASE))
  ;;calculate the test 3d average ratios
  (setq LEN (length 3D_RATIOS))
  (setq REP (fix (/ LEN NUM_3D)))
  (setq CNTR 0)
  (setq X NIL)
  (setq 3D_TEST (list))
  (setq ROW_LIST (list))
  (repeat REP
    (setq SUM 0)
    (setq CNTRX 0)
    (repeat NUM_3D
      (setq SUM
	     (+ SUM (setq X (nth (+ CNTR (* CNTRX REP)) 3D_RATIOS)))
      )
      (setq CNTRX (1+ CNTRX))
      (setq ROW_LIST (append ROW_LIST (list (/ 1 X))))
    )					;end repeat loops
    (setq AVG (list (/ 1 (/ SUM NUM_3D))))
    (setq 3D_TEST (append 3D_TEST AVG))
    (setq CNTR (1+ CNTR))
  )					;end repeat offset

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
  ;;modify to get real dwg average scores
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
  ;;calcualte the drawing 3d average ratios
  (setq LEN (length 3D_RATIOS))
  (setq REP (fix (/ LEN NUM_3D)))
  (setq CNTR 0)
  (setq 3D_DWGS (list))

  (repeat NUM_3D
    ;;calculate real average
    (setq CNTR (1+ CNTR))		;end repeat loops
    (setq offsetx (- (* cntr rep) rep))

    ;; calculate 2d graphics index
    (setq 2d_indx_dwg
	   (/ 4
	      (+ (nth (+ offsetx 4) 3D_RATIOS)
		 (nth (+ offsetx 5) 3D_RATIOS)
		 (nth (+ offsetx 6) 3D_RATIOS)
		 (nth (+ offsetx 7) 3D_RATIOS)
	      )
	   )
    )

    ;; calculate Disk index
    (setq disk_indx_dwg
	   (/ 3
	      (+ (nth (+ offsetx 0) 3D_RATIOS)
		 (nth (+ offsetx 1) 3D_RATIOS)
		 (nth (+ offsetx 2) 3D_RATIOS)
	      )
	   )
    )

    ;; calculate CPU index
    (setq cpu_indx_dwg
	   (/ 1
	      (+ (nth (+ offsetx 3) 3D_RATIOS)
	      )
	   )
    )
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;; 
;    ;; calculate 3d total index
    (setq 3d2dtotal_indx_dwg
	   (/ (+ 2d_indx_dwg
		 disk_indx_dwg
		 cpu_indx_dwg
	      )
	      3
	   )
    )					; end setq

    (setq 3d2dtotal_indx_dwg (list 3d2dtotal_indx_dwg))
    (setq 3D_DWGS (append 3D_DWGS 3d2dtotal_indx_dwg))


    )					; end repeat
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

  ;; calculate 2d graphics index
  (setq	2d_indx
	 (/ 4
	    (+ (/ 1 (nth 4 3D_TEST))
	       (/ 1 (nth 5 3D_TEST))
	       (/ 1 (nth 6 3D_TEST))
	       (/ 1 (nth 7 3D_TEST))
	    )
	 )
  )
  ;; calculate disk index
  (setq	disk_indx
	 (/ 3
	    (+ (/ 1 (nth 0 3D_TEST))
	       (/ 1 (nth 1 3D_TEST))
	       (/ 1 (nth 2 3D_TEST))
	    )
	 )
  )
  ;; calculate CPU index
  (setq	cpu_indx
	 (/ 1
	    (+ (/ 1 (nth 3 3D_TEST))
	    )
	 )
  )

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;; 
;;adjust number of digits after decimal based on main index value
 (cond
       ((>= 2d_indx 100) (progn (setq fillspace "")   (setq filldash "")                  (setq decdigits 0)))
       ((>= 2d_indx 10)  (progn (setq fillspace "  ") (setq filldash " - - - - -")        (setq decdigits 1)))
       ((>= 2d_indx 0)   (progn (setq fillspace "   ") (setq filldash " - - - - - - - -") (setq decdigits 2)))
      );;end cond
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;; 

  ;; Begin writng index information to file and drawing
  (setq FNAME DATA_FILE)
  (setq FILE (open FNAME "a"))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;; 
  ;;  Write drawing names to file/screen
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;; 

  (command "_text"
	   ""
	   (write-line
	     (strcat                 "Drawing (2D)===>>          "
		fillspace     DWG1   "    "
		fillspace     DWG2   "    "
		fillspace     DWG3   "    "
		fillspace     DWG4	
                fillspace            "      Test Index"
		    ); end strcat
	     FILE
	   ); end write-line
  ); end command					

  (command
    "_text"
    ""
    (write-line (strcat
      "- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -"
      filldash); end strcat
      FILE
    )
  )

  (setq CNTR 0)
  (setq CNTRX 0)
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;  
  ;; print one line of scores and average for each test
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;    
  (repeat NUM_TEST
    (setq XX (nth CNTR ROW_LIST))
    (setq ajl1 xx)

    ;;add spaces BEFORE, based on length of next score to post
    (setq X (cond ((< XX 9.9) "       ");; adjust here
		  ((and (>= XX 9.9) (< XX 99.9)) "      ");; adjust here
		  ((and (>= XX 99.9) (< XX 999.9)) "     ");; adjust here
		  ((and (>= XX 999.9) (< XX 99999.9)) "    ");; adjust here
	    )				;end cond-->> increase last top value to avoid error
    )					;end setq
    (setq ajl1b x)

    (repeat NUM_3D

      ;;find length of test score coming up next 
      (setq cntrxxx (1+ cntr))
      (setq XXX (nth cntrxxx row_list))

      ;;add spaces AFTER, based on score comming up next test
      (setq
	X
	 (strcat X
		 (rtos (nth CNTR ROW_LIST) 2 decdigits);; adjust here

		 (cond ((< XXX 9.9) "          ");; adjust here
		       ((and (>= XXX 9.9) (< XXX 99.9)) "         ");; adjust here
		       ((and (>= XXX 99.9) (< XXX 999.9)) "        ");; adjust here
		       ((and (>= XXX 999.9) (< XXX 99999.9)) "       ");; adjust here
		 )			;end cond-->> increase last top value to avoid error
	 )				;end strcat
      )					;end setq

      (setq ajl2 x)
      (setq CNTR (1+ CNTR))
    )					;end repeat num_3d

    ;;grab test name and append to front of list
    (setq X (strcat (nth CNTRX TST_NAME) X))

    (setq ajl3 x)

    ;;format output of score for each test
    ;;get test score
    (setq xtemp (nth CNTRX 3D_TEST))
    (setq ajl4 xtemp)

    ;;add spaces based on length of previous score posted and average test score
    (setq xtempx
	   (cond ((< XXX 9.9) "")
		 ((and (>= XXX 9.9) (< XXX 99.9)) " ")
		 ((and (>= XXX 99.9) (< XXX 999.9)) "  ")
		 ((and (>= XXX 999.9) (< XXX 99999.9)) "   ")
	   )				;end cond-->> increase last top value to avoid error
    )					; end setq xtempx

    (setq xxtemp
	   (cond ((< Xtemp 9.9) "  ");; adjust here
		 ((and (>= Xtemp 9.9) (< Xtemp 99.9)) " ");; adjust here
		 ((and (>= Xtemp 99.9) (< Xtemp 999.9)) "");; adjust here
		 ((and (>= Xtemp 999.9) (< Xtemp 99999.9)) "");; adjust here
	   )				;end cond-->> increase last top value to avoid error
    )					;end setqtq
    ;;append spaces to string
    (setq X (strcat X xtempx))
    (setq X (strcat X xxtemp))

    (setq ajl5 x)
    ;;append spaces on score to string
    (setq X (strcat X (rtos (nth CNTRX 3D_TEST) 2 decdigits)));; adjust here
    (setq ajl6 x)
    (command "_text" "" (write-line X FILE))
    (setq CNTRX (1+ CNTRX))
    (setq X "")

  )					;end repeat num_test
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;  
  ;;done with individual scores

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;  
  ;;write dwg averages
  (command
    "_text"
    ""
    (write-line (strcat
      "- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -"
      filldash); end strcat
      FILE
    )
    ;;end write-line
  )
  ;;end command


  ;;output 3d DWG AVERAGES HERE 
  ;;calcualte spaces to add between scores based on length of score
  ;;prime the pump

  (setq idi (nth 0 3D_DWGS))
  (setq	space1
	 (cond ((< idi 9.9) "        ");; adjust here
	       ((and (>= idi 9.9) (< idi 99.9)) "       ");; adjust here
	       ((and (>= idi 99.9) (< idi 999.9)) "      ");; adjust here
	       ((and (>= idi 999.9) (< idi 99999.9)) "     ");; adjust here
	 )				;end cond-->> increase last top value to avoid error
  )					; end setq space1

  (setq idi (nth 1 3D_DWGS))
  (setq	space2  
	 (cond ((< idi 9.9) "          ");; adjust here
	       ((and (>= idi 9.9) (< idi 99.9)) "         ");; adjust here
	       ((and (>= idi 99.9) (< idi 999.9)) "        ");; adjust here
	       ((and (>= idi 999.9) (< idi 99999.9)) "       ");; adjust here
	 )				;end cond-->> increase last top value to avoid error

  )					; end setq space2

  (setq idi (nth 2 3D_DWGS))
  (setq	space3
	 (cond ((< idi 9.9) "          ")
	       ((and (>= idi 9.9) (< idi 99.9)) "         ");; adjust here
	       ((and (>= idi 99.9) (< idi 999.9)) "        ");; adjust here
	       ((and (>= idi 999.9) (< idi 99999.9)) "       ");; adjust here
	 )				;end cond-->> increase last top value to avoid error

  )					; end setq space3

  (setq idi (nth 3 3D_DWGS))
  (setq	space4
	 (cond ((< idi 9.9) "          ")
	       ((and (>= idi 9.9) (< idi 99.9)) "         ");; adjust here
	       ((and (>= idi 99.9) (< idi 999.9)) "        ");; adjust here
	       ((and (>= idi 999.9) (< idi 99999.9)) "       ");; adjust here
	 )				;end cond-->> increase last top value to avoid error

  )					; end setq space4

  (command "_text"
	   ""
	   (write-line
	     (strcat
	       "Individual Dwg Index    "
	       space1
	       (rtos (nth 0 3D_DWGS) 2 decdigits);; adjust here
	       space2
	       (rtos (nth 1 3D_DWGS) 2 decdigits);; adjust here
	       space3
	       (rtos (nth 2 3D_DWGS) 2 decdigits);; adjust here
	       space4
	       (rtos (nth 3 3D_DWGS) 2 decdigits);; adjust here
	     )				;end strcat

	     FILE
	   )				;end write-line
  )					;end command

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
					;write total index number
  (command "_text" "" (write-line "" FILE))
  
  (command "_text" ""
   (write-line "********************************" FILE))
  
  ;;add spaces based on digits in score
  (command "_text" ""
    (write-line (strcat "C2011 Total Index   ="  fillspace "  N/A " ) FILE ));;end command

  (command "_text" ""
   (write-line "********************************" FILE))

  ;;add spaces based on digits in score

  (command "_text" ""
   (write-line	(strcat "3D Graphics Index   =" fillspace "  N/A " ) FILE))

  ;;add spaces based on digits in score
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
  (setq x 2d_indx)
  (setq	xx
	 (cond ((< x 9.9) "   ")
	       ((and (>= x 9.9) (< x 99.9)) "  ")
	       ((and (>= x 99.9) (< x 999.9)) " ")
	       ((and (>= x 999.9) (< x 99999.9)) "")
	 )				;end cond-->> increase last top value to avoid errors
  )					; end setq xx  
  (command "_text"
	   ""
	   (write-line			;   "
	     (strcat "2D Graphics Index   = " xx (rtos 2d_indx 2 decdigits));; adjust here
	     FILE
	   )
  )

  ;;add spaces based on digits in score
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
  (setq x disk_indx)
  (setq	xx
	 (cond ((< x 9.9) "   ")
	       ((and (>= x 9.9) (< x 99.9)) "  ")
	       ((and (>= x 99.9) (< x 999.9)) " ")
	       ((and (>= x 999.9) (< x 99999.9)) "")
	 )				;end cond-->> increase last top value to avoid error
  )					; end setq xx  
  (command "_text"
	   ""
	   (write-line			;   "
	     (strcat "Disk Index          = "
		     xx
		     (rtos disk_indx 2 decdigits);; adjust here
	     )
	     FILE
	   )
  )

  ;;add spaces based on digits in score
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
  (setq x cpu_indx)
  (setq	xx
	 (cond ((< x 9.9) "   ")
	       ((and (>= x 9.9) (< x 99.9)) "  ")
	       ((and (>= x 99.9) (< x 999.9)) " ")
	       ((and (>= x 999.9) (< x 99999.9)) "")
	 )				;end cond-->> increase last top value to avoid error
  )					; end setq xx  
  (command
    "_text"
    ""
    (write-line				;   "       
      (strcat "CPU Index           = " xx (rtos cpu_indx 2 decdigits));; adjust here
      FILE
    )
  )

  (command "_text"
	   ""
	   (write-line "********************************" FILE)
  )
  (close FILE)
);; end output_2d
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Read current test results in from file
(defun OUTPUT_3D ()
  (setq FNAME 3DCUR_FILE)
  (setq FILE (open FNAME "r"))
  (setq 3D_LIST_ALL (LIST_IN FILE))
  (close FILE)  
  ;;strip away notes, leaving just numbers
  (setq TMP_LIST 3D_LIST_ALL)  ;; for later use
  (setq 3D_LIST_ALL (STRIP 3D_LIST_ALL))
  (setq LOOPS (fix (car 3D_LIST_ALL)))
  (setq 3D_LIST_ALL (cdr 3D_LIST_ALL))  ;;get name of tests
  (setq LEN (length TMP_LIST))
  (setq NUM_TEST (/ LEN NUM_3D LOOPS))
  (setq TST_NAME (list))
  (setq CNTR 1)  ;; skip number of loops
  (repeat NUM_TEST
    (setq NAM (list (car (nth CNTR TMP_LIST))))
    (setq TST_NAME (append TST_NAME NAM))
    (setq CNTR (1+ CNTR))
  )					;end repeat
  ;;figure average times
  (setq LEN (length 3D_LIST_ALL))
  (setq OFFSET (fix (/ LEN LOOPS)))
  (setq CNTR 0)
  (setq 3D_CUR (list))
  (repeat OFFSET
    (setq SUM 0)
    (setq CNTRX 0)
    (repeat LOOPS
      (setq SUM (+ SUM (nth (+ CNTR (* CNTRX OFFSET)) 3D_LIST_ALL)))
      (setq CNTRX (1+ CNTRX))
    )					;end repeat loops
    (setq AVG (/ SUM LOOPS))    ;; set minimum time
    (if	(< AVG 0.05)
      (setq AVG 0.05)
    )

    (setq AVG (list AVG))
    (setq 3D_CUR (append 3D_CUR AVG))
    (setq CNTR (1+ CNTR))
  )					;end repeat offset

  ;; Read base 3dtest results in from file
  (setq FNAME BASE_FILE)
  (setq FILE (open FNAME "r"))
  (setq 3D_BASE (LIST_IN FILE))
  (close FILE)
  ;;remove first pair- description
  (setq 3D_BASE (cdr 3D_BASE))
  ;;strip away notes, leaving just numbers
  (setq 3D_BASE (STRIP 3D_BASE))

  ;;calculate ratios of current times to base times
  (setq 3D_RATIOS (mapcar '/ 3D_CUR 3D_BASE))
  ;;calculate the test 3d average ratios
  (setq LEN (length 3D_RATIOS))
  (setq REP (fix (/ LEN NUM_3D)))
  (setq CNTR 0)
  (setq X NIL)
  (setq 3D_TEST (list))
  (setq ROW_LIST (list))
  (repeat REP
    (setq SUM 0)
    (setq CNTRX 0)
    (repeat NUM_3D
      (setq SUM
	     (+ SUM (setq X (nth (+ CNTR (* CNTRX REP)) 3D_RATIOS)))
      )
      (setq CNTRX (1+ CNTRX))
      (setq ROW_LIST (append ROW_LIST (list (/ 1 X))))
    )					;end repeat loops
    (setq AVG (list (/ 1 (/ SUM NUM_3D))))
    (setq 3D_TEST (append 3D_TEST AVG))
    (setq CNTR (1+ CNTR))
  )					;end repeat offset

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
  ;;modify to get real dwg average scores
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
  ;;calcualte the drawing 3d average ratios
  (setq LEN (length 3D_RATIOS))
  (setq REP (fix (/ LEN NUM_3D)))
  (setq CNTR 0)
  (setq 3D_DWGS (list))

  (repeat NUM_3D
    ;;calculate real average
    (setq CNTR (1+ CNTR))		;end repeat loops
    (setq offsetx (- (* cntr rep) rep))


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
    ;; calculate 3d graphics index for each drawing--ADJUSTED TO GIVE STANDARD AVERAGE
    (setq 3D_INDX_dwg
	    (/   (+ (/ 1 (nth (+ offsetx 0) 3D_RATIOS))
		    (/ 1 (nth (+ offsetx 1) 3D_RATIOS))
		    (/ 1 (nth (+ offsetx 2) 3D_RATIOS))
		    (/ 1 (nth (+ offsetx 3) 3D_RATIOS)))
            4);;end first divide
    )
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;; 
    ;; calculate 3d total index
    (setq 3d2dtotal_indx_dwg
	   (/ (+ 3D_INDX_dwg
		 	      )
	      1 
	   )
    )					; end setq
    (setq 3d2dtotal_indx_dwg (list 3d2dtotal_indx_dwg))
    (setq 3D_DWGS (append 3D_DWGS 3d2dtotal_indx_dwg))
    )					; end repeat
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
  ;; calculate 3d graphics index--MODIFIED TO GIVE STANDARD AVERAGE
  (setq	3D_INDX
	 (/ 
	    (+ (nth 0 3D_TEST)
	       (nth 1 3D_TEST)
	       (nth 2 3D_TEST)
	       (nth 3 3D_TEST))
	 4 );;END DIVIDE
  )
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;; 
;;adjust number of digits after decimal based on main index value
 (cond
       ((>= 3D_INDX 100) (progn (setq fillspace "")    (setq filldash "")                 (setq decdigits 0)))
       ((>= 3D_INDX 10)  (progn (setq fillspace "  ")  (setq filldash " - - - - -")       (setq decdigits 1)))
       ((>= 3D_INDX 0)   (progn (setq fillspace "   ") (setq filldash " - - - - - - - -") (setq decdigits 2)))
      );;end cond
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;; 

  ;; Begin writng index information to file and drawing
  (setq FNAME DATA_FILE)
  (setq FILE (open FNAME "a"))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;; 
  ;;  Write drawing names to file/screen
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;; 

  (command "_text"
	   ""
	   (write-line
	     (strcat                 "Drawing (3D)===>>          "
		fillspace     DWG5   "    "
		fillspace     DWG6   "    "
		fillspace     DWG7   "    "
		fillspace     DWG8	
                fillspace            "      Test Index"
		    ); end strcat
	     FILE
	   ); end write-line
  ); end command					

  (command
    "_text"
    ""
    (write-line (strcat
      "- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -"
      filldash); end strcat
      FILE
    )
  )

  (setq CNTR 0)
  (setq CNTRX 0)
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;  
  ;; print one line of scores and average for each test
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;    
  (repeat NUM_TEST
    (setq XX (nth CNTR ROW_LIST))
    (setq ajl1 xx)

    ;;add spaces BEFORE, based on length of next score to post
    (setq X (cond ((< XX 9.9) "       ");; adjust here
		  ((and (>= XX 9.9) (< XX 99.9)) "      ");; adjust here
		  ((and (>= XX 99.9) (< XX 999.9)) "     ");; adjust here
		  ((and (>= XX 999.9) (< XX 99999.9)) "    ");; adjust here
	    )				;end cond-->> increase last top value to avoid error
    )					;end setq
    (setq ajl1b x)

    (repeat NUM_3D

      ;;find length of test score coming up next 
      (setq cntrxxx (1+ cntr))
      (setq XXX (nth cntrxxx row_list))

      ;;add spaces AFTER, based on score comming up next test
      (setq
	X
	 (strcat X
		 (rtos (nth CNTR ROW_LIST) 2 decdigits);; adjust here

		 (cond ((< XXX 9.9) "          ");; adjust here
		       ((and (>= XXX 9.9) (< XXX 99.9)) "         ");; adjust here
		       ((and (>= XXX 99.9) (< XXX 999.9)) "        ");; adjust here
		       ((and (>= XXX 999.9) (< XXX 99999.9)) "       ");; adjust here
		 )			;end cond-->> increase last top value to avoid error
	 )				;end strcat
      )					;end setq

      (setq ajl2 x)
      (setq CNTR (1+ CNTR))
    )					;end repeat num_3d

    ;;grab test name and append to front of list
    (setq X (strcat (nth CNTRX TST_NAME) X))

    (setq ajl3 x)

    ;;format output of score for each test
    ;;get test score
    (setq xtemp (nth CNTRX 3D_TEST))
    (setq ajl4 xtemp)

    ;;add spaces based on length of previous score posted and average test score
    (setq xtempx
	   (cond ((< XXX 9.9) "")
		 ((and (>= XXX 9.9) (< XXX 99.9)) " ")
		 ((and (>= XXX 99.9) (< XXX 999.9)) "  ")
		 ((and (>= XXX 999.9) (< XXX 99999.9)) "   ")
	   )				;end cond-->> increase last top value to avoid error
    )					; end setq xtempx

    (setq xxtemp
	   (cond ((< Xtemp 9.9) "  ");; adjust here
		 ((and (>= Xtemp 9.9) (< Xtemp 99.9)) " ");; adjust here
		 ((and (>= Xtemp 99.9) (< Xtemp 999.9)) "");; adjust here
		 ((and (>= Xtemp 999.9) (< Xtemp 99999.9)) "");; adjust here
	   )				;end cond-->> increase last top value to avoid error
    )					;end setq
    ;;append spaces to string
    (setq X (strcat X xtempx))
    (setq X (strcat X xxtemp))

    (setq ajl5 x)
    ;;append spaces on score to string
    (setq X (strcat X (rtos (nth CNTRX 3D_TEST) 2 decdigits)));; adjust here
    (setq ajl6 x)
    (command "_text" "" (write-line X FILE))
    (setq CNTRX (1+ CNTRX))
    (setq X "")

  )					;end repeat num_test
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;  
  ;;done with individual scores

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;  
  ;;write dwg averages
  (command
    "_text"
    ""
    (write-line (strcat
      "- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -"
      filldash); end strcat
      FILE
    )
    ;;end write-line
  )
  ;;end command


  ;;output 3d DWG AVERAGES HERE 
  ;;calcualte spaces to add between scores based on length of score
  ;;prime the pump

  (setq idi (nth 0 3D_DWGS))
  (setq	space1
	 (cond ((< idi 9.9) "        ");; adjust here
	       ((and (>= idi 9.9) (< idi 99.9)) "       ");; adjust here
	       ((and (>= idi 99.9) (< idi 999.9)) "      ");; adjust here
	       ((and (>= idi 999.9) (< idi 99999.9)) "     ");; adjust here
	 )				;end cond-->> increase last top value to avoid error
  )					; end setq space1

  (setq idi (nth 1 3D_DWGS))
  (setq	space2  
	 (cond ((< idi 9.9) "          ");; adjust here
	       ((and (>= idi 9.9) (< idi 99.9)) "         ");; adjust here
	       ((and (>= idi 99.9) (< idi 999.9)) "        ");; adjust here
	       ((and (>= idi 999.9) (< idi 99999.9)) "       ");; adjust here
	 )				;end cond-->> increase last top value to avoid error

  )					; end setq space2

  (setq idi (nth 2 3D_DWGS))
  (setq	space3
	 (cond ((< idi 9.9) "          ")
	       ((and (>= idi 9.9) (< idi 99.9)) "         ");; adjust here
	       ((and (>= idi 99.9) (< idi 999.9)) "        ");; adjust here
	       ((and (>= idi 999.9) (< idi 99999.9)) "       ");; adjust here
	 )				;end cond-->> increase last top value to avoid error

  )					; end setq space3

  (setq idi (nth 3 3D_DWGS))
  (setq	space4
	 (cond ((< idi 9.9) "          ")
	       ((and (>= idi 9.9) (< idi 99.9)) "         ");; adjust here
	       ((and (>= idi 99.9) (< idi 999.9)) "        ");; adjust here
	       ((and (>= idi 999.9) (< idi 99999.9)) "       ");; adjust here
	 )				;end cond-->> increase last top value to avoid error

  )					; end setq space4

  (command "_text"
	   ""
	   (write-line
	     (strcat
	       "Individual Dwg Index    "
	       space1
	       (rtos (nth 0 3D_DWGS) 2 decdigits);; adjust here
	       space2
	       (rtos (nth 1 3D_DWGS) 2 decdigits);; adjust here
	       space3
	       (rtos (nth 2 3D_DWGS) 2 decdigits);; adjust here
	       space4
	       (rtos (nth 3 3D_DWGS) 2 decdigits);; adjust here
	     )				;end strcat

	     FILE
	   )				;end write-line
  )					;end command

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
					;write total index number
  (command "_text" "" (write-line "" FILE))
  (command "_text"
	   ""
	   (write-line "********************************" FILE)
  )

  (command "_text" ""
    (write-line (strcat "C2011 Total Index   ="  fillspace    "  N/A"  ) FILE ))

  (command "_text" ""
    (write-line "********************************" FILE))

  ;;add spaces based on digits in score
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
  (setq x 3D_INDX)
  (setq	xx
	 (cond ((< x 9.9) "   ")
	       ((and (>= x 9.9) (< x 99.9)) "  ")
	       ((and (>= x 99.9) (< x 999.9)) " ")
	       ((and (>= x 999.9) (< x 99999.9)) "")
	 )				;end cond-->> increase last top value to avoid error
  )					; end setq xx
  (command "_text"
	   ""
	   (write-line			;   "
	     (strcat "3D Graphics Index   = " xx (rtos 3D_INDX 2 decdigits));; adjust here
	     FILE
	   )
  )

  (command "_text"  ""
    (write-line	(strcat "2D Graphics Index   ="  fillspace  "  N/A "  ) FILE ))

   (command "_text"  ""
    (write-line	(strcat "Disk Index          ="  fillspace "  N/A " )  FILE ))

  (command "_text"  ""
    (write-line	(strcat "CPU Index           ="  fillspace  "  N/A " )  FILE ))

  (command "_text"
	   ""
	   (write-line "********************************" FILE)
  )
  (close FILE)
);; end output_3d
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;



;; first erase all to remove any junk
(command "_erase" "_all" "")
(command "_style" "cadalyst" "monotxt" "0.0" "1.0" "0" "_n" "_n" "_n")
(command "_text" "0,0" "2" "0" "")


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;Find Test Type for new option
(setq FNAME CNFG_FILE)
(setq FILE (open FNAME "r"))
(setq CNFG_LIST (LIST_IN FILE))
(close FILE)
(setq TEST_TYPE (car (cdr (nth 8 CNFG_LIST))))
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;check to see if other base file is named...act accordingly
(if (= fname_data_ref nil)
      (cond
       ((= TEST_TYPE "3D2D")
	 (progn (setq BASE_FILE "C2011_std_3d2d.dta") (OUTPUT_3D2D))
       )
       ((= TEST_TYPE "2D")
	 (progn (setq BASE_FILE "C2011_std_2d.dta") (OUTPUT_2D))
       )
       ((= TEST_TYPE "3D")
	 (progn (setq BASE_FILE "C2011_std_3d.dta") (OUTPUT_3D))
       )
      )
(princ)

);; end if

(if (/= fname_data_ref nil)
      (cond
       ((= TEST_TYPE "3D2D")
	 (progn (setq BASE_FILE fname_data_ref) (OUTPUT_3D2D))
       );;end type 3d2d
       ((= TEST_TYPE "2D")
	 (progn (setq BASE_FILE fname_data_ref) (OUTPUT_2D))
       );;end type 2d
       ((= TEST_TYPE "3D")
	 (progn (setq BASE_FILE fname_data_ref) (OUTPUT_3D))
       );;end type 3d
      );;end cond
);; end if
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


;;compute averge test loop time
(setq FNAME "tot_time.tmp")
(setq FILE (open FNAME "r"))
(setq TIME (LIST_IN FILE))
(close FILE)
(setq COMMENT (cadr (car TIME)))


;; get first item
(setq TIME (cdr TIME))
;; remove first item from list
(setq TIME (STRIP TIME))
(setq TOTAL_TIME (- (cadr TIME) (car TIME)))
(setq LOOP_TIME (/ TOTAL_TIME LOOPS))
(setq LOOP_TIME (/ LOOP_TIME 60))
;;convert to minutes
(setq LOOP_TIMEx (rtos LOOP_TIME 2 0))
;;convert to string; decimal format with 1 decimal
(setq LOOP_TIMEx (strcat LOOP_TIMEx " min)"))
;;add units

(setq FNAME DATA_FILE)
(setq FILE (open FNAME "a"))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(setq x LOOP_TIME)
(setq xx
       (cond ((< x 9.9) "   ")
	     ((and (>= x 9.9) (< x 99.9)) "  ")
	     ((and (>= x 99.9) (< x 999.9)) " ")
	     ((and (>= x 999.9) (< x 99999.9)) "")
       )				;end cond
)					;end setq xx  

(command "_text"
	 ""
	 (write-line
	   (strcat "(Single Loop Time   = "
		   xx
		   LOOP_TIMEx
	   )
	   FILE
	 )
)					; end write-line

(command "_text" "" (write-line "" FILE))
(close FILE)
(command "_text" "" (strcat "Comment: " COMMENT))

(command "_text"			"_j"
	 "_fit"			"0,5"
	 "160,5"		"15"
	 "CADALYST Systems Benchmark 2011 v5.3b"
	)
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;



(command "_ucsicon" "_off")
(command "_zoom" "_e" "_zoom" "0.97x")
(princ)					;end



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Quick/dirty routine:
;; Remove semicolons at begining of line below to append actual test times to data file.

(load "times")

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;find if Compare Option is ON or OFF
;; Read information in from file 
(setq FNAME CNFG_FILE)
(setq FILE (open FNAME "r"))
(setq CNFG_LIST (LIST_IN FILE))
(close FILE)

;;for new compare option
;;if ON, call compare routine
(setq COMP_OPT (car (cdr (nth 7 CNFG_LIST))));;<<---verify number

(cond ((= COMP_OPT "On") (load "C2011_compare"))
      ((= COMP_OPT "Off") (exit))
      ((= COMP_OPT "") (exit))
)					; end cond
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

